bases = c("A", "C", "G", "T")

mutationSpectrum <- function( variantCalls, tallyFile, study, context = 1 ){
  stopifnot(class(variantCalls) == "data.frame")
  chromosomes = unique( variantCalls$Chrom )
  variantCalls$Prefix = ""
  variantCalls$Suffix = ""
  for(chrom in chromosomes){
    sel = variantCalls$Chrom == chrom
    minpos = max( min( variantCalls$Start[sel] ) - 10 - context, 0 )
    maxpos = max( variantCalls$End[sel] ) + 10 + context
    reference = h5read( tallyFile, paste( study, chrom, "Reference", sep = "/" ), index = list(minpos:maxpos)) + 1
    offset = minpos
    variantCalls$Prefix[sel] = sapply( variantCalls$Start[sel], function(pos) paste(bases[reference[ (pos - context - offset + 1):(pos - offset) ]], collapse="") )
    variantCalls$Suffix[sel] = sapply( variantCalls$End[sel], function(pos) paste(bases[reference[ (pos - offset + 2):(pos + context - offset + 1) ]], collapse="") )
    variantCalls$Context[sel] = sapply( variantCalls$Start[sel], function(pos) paste(bases[reference[ (pos - context - offset + 1):(pos - offset + context + 1) ]], collapse="") )
  }
  transitions = c( "T>G" = "A>C", "T>C" = "A>G", "T>A" = "A>T", "G>C" = "C>G", "G>A" = "C>T", "C>A" = "G>T" )
  variantCalls$Transition = paste(variantCalls$refAllele, variantCalls$altAllele, sep=">")
  variantCalls$Transition[variantCalls$Transition %in% names(transitions)] = transitions[ variantCalls$Transition[variantCalls$Transition %in% names(transitions)] ]
  return( variantCalls[,c("refAllele","altAllele","Sample","Prefix","Suffix","Transition","Context")] )
}