mismatchPlot <- function( data, sampledata, samples=sampledata$Sample, windowsize, position ){
  sampleColumns = sampledata$Column[ match(samples, sampledata$Sample) ]
  stopifnot(length(sampleColumns)>0, !any(is.na(sampleColumns)))
  stopifnot(is.numeric(windowsize), length(windowsize)==1,
            is.numeric(position),   length(position)==1)
  stopifnot( "Counts" %in% names(data), "Coverages" %in% names(data), "Deletions" %in% names(data) )
  cvg = melt( data$Coverages[ sampleColumns,,,drop=FALSE ] ) 
  colnames(cvg) = c("Sample", "Strand", "Position", "Coverage")
  cvg$Sample = samples[ cvg$Sample ]
  cvg$Coverage[cvg$Strand == 2] <- -cvg$Coverage[cvg$Strand == 2]
  counts = melt( data$Counts[ ,sampleColumns,,,drop=FALSE ] )
  colnames(counts) <- c("Base", "Sample", "Strand", "Position", "Count")
  dels = melt( data$Deletions[ sampleColumns,,,drop=FALSE ] )
  colnames(dels) = c("Sample","Strand","Position","Deletions")
  dels$Deletions[dels$Strand == 2] <- -dels$Deletions[dels$Strand == 2]
  dels$Coverage = cvg$Coverage
  dels$Sample = samples[ dels$Sample ]
  dels$Type = "Del"
  counts$Sample = samples[ counts$Sample ]
  for( i in 1:4 ){
    counts$Count[ counts$Base == i ] = counts$Count[ counts$Base == i ] + counts$Count[ counts$Base == i + 8 ]
  }
  counts = counts[ counts$Base %in% 1:8, ]
  plot_bases = c( "A_lq", "C_lq", "G_lq", "T_lq", "A", "C", "G", "T" )
  counts$Base = plot_bases[counts$Base]
  counts$Base = factor( counts$Base, levels = c("A", "C", "G", "T", "A_lq", "C_lq", "G_lq", "T_lq") )
  cvg$Position = cvg$Position - windowsize - 1
  counts$Position = counts$Position - windowsize - 1
  dels$Position = dels$Position - windowsize - 1
  ## calculate the stacking
  counts$Bottom = 0
  tmp = rep(0, 2*windowsize )
  for( sample in unique( counts$Sample ) ){
    for( strand in 1:2 ){
      for( b in levels(counts$Base) ){
        ss = counts$Count[counts$Strand == strand & counts$Base == b & counts$Sample == sample]
        counts$Count[ counts$Strand == strand & counts$Base == b & counts$Sample == sample ] = counts$Count[ counts$Strand == strand & counts$Base == b & counts$Sample == sample ] + tmp
        counts$Bottom[ counts$Strand == strand & counts$Base == b & counts$Sample == sample ] = tmp
        tmp = tmp + ss
      }
      tmp = rep(0, 2*windowsize )
    }
  }
  counts$Count[counts$Strand == 2] <- -1*counts$Count[counts$Strand == 2]
  counts$Bottom[counts$Strand == 2] <- -1*counts$Bottom[counts$Strand == 2]
  ggplot( cvg ) +
    geom_rect( data = cvg, aes_string( xmin = 'Position', xmax = 'Position + 1', ymax = 'Coverage', ymin = '0' ), fill = "#C5C5C5" ) +
    geom_rect( data = counts, aes_string( xmin = 'Position', xmax = 'Position + 1', ymin = 'Bottom', ymax = 'Count', fill = 'Base' ) ) +
    geom_rect( data = dels, aes_string( xmin = 'Position', xmax = 'Position + 1', ymin = 'Coverage', ymax = 'Coverage + Deletions', fill = 'Type' ) ) +
    scale_fill_manual( values = c("A" = "#15D515", "C" = "#D51515", "G" = "#1515D5", "T" = "#D5D515", "Del" = "purple", "A_lq"="#75D575", "C_lq"="#D57575", "G_lq"="#7575D5", "T_lq"="#D5D575") ) +
    geom_hline( aes( yintercept = 0 ), colour = "#555555" ) +
    geom_vline( aes( xintercept = 0:1 ), colour = "#555555" ) +
    scale_x_continuous(
      breaks = c( seq( -1*windowsize, -10, 10 ), 0, seq( 10, windowsize, 10 ) ),
      labels = paste( c( seq( -1*windowsize, -10, 10 ), position, seq( 10, windowsize, 10 ) ) ),
      expand = c( 0, 0 )
      ) +
    facet_wrap( ~ Sample, ncol = 1 ) +
    theme(axis.text.x  = element_text(angle=45, vjust=0.5, size = 12), legend.position = "top")
}

geom_h5vc <- function( data, sampledata, samples=sampledata$Sample, windowsize, position, dataset, ... ){
  sampleColumns = sampledata$Column[ match(samples, sampledata$Sample) ]
  stopifnot(length(sampleColumns)>0, !any(is.na(sampleColumns)))
  stopifnot(is.numeric(windowsize), length(windowsize)==1,
            is.numeric(position),   length(position)==1)
  dat = melt( data[[dataset]][ sampleColumns,,,drop=FALSE ] ) 
  colnames(dat) = c("Sample", "Strand", "Position", "Value")
  dat$Sample = samples[ dat$Sample ]
  dat$Value[dat$Strand == 2] <- -dat$Value[dat$Strand == 2]
  dat$Position = dat$Position - windowsize - 1
  ret = geom_rect( data = dat, aes_string( xmin = 'Position', xmax = 'Position + 1', ymax = 'Value', ymin = '0' ), ...)
  return(ret)
}
